searchData={"items":[{"type":"module","title":"PintBroker","doc":"A simple, pint-sized MQTT broker that can be used for testing and development\n\n> ##","ref":"PintBroker.html"},{"type":"module","title":"Warning {: .warning} - PintBroker","doc":">\n> This is not indended for production use and makes no attempts for\n> large connection scaling and handling. It is also not considered\n> feature complete, but handles most simple use cases.\n\n**Supported:**\n\n* Simple, unencrypted TCP connections\n* [MQTT v3.1.1](http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.pdf)\n  * QoS 0\n  * Connect, publish, subscribe, and unsubscribe\n  * Ping requests\n  * Rule forwarding (see below)\n\n**Unsupported:**\n\n* SSL connections\n* QoS 1 and 2\n* [MQTT v5](https://docs.oasis-open.org/mqtt/mqtt/v5.0/mqtt-v5.0.pdf)\n\nYou can specify custom `:gen_tcp` options with `:overrides` key when starting\nthe server.","ref":"PintBroker.html#module-warning-warning"},{"type":"module","title":"Rule forwarding - PintBroker","doc":"Many production setups will have a few topics with rules that forward\nmessages to a handler such as an SQS queue or central service. This allows\nfor scaling of many devices to communicate with a few nodes. For testing,\nyou can specify rules when starting the broker which will forward\n`Tortoise311.Package.Publish` structs to a handler function or process in\norder to mimic this rule forwarding behavior. See `add_rule/3` for more\ninformation.\n\n**Example:**\n\n```elixir\niex> s = self()\n\niex> handler1 = fn pub -> send(s, pub) end\n\niex> PintBroker.start_link(rules: [{\"my/+/test/topic\", handler1}])\n{:ok, #PID }\n\n# You can publish from the broker or another client\niex> PintBroker.publish(\"my/first/test/topic\", \"hello world\")\n\niex> flush()\n%Tortoise311.Package.Publish{\n  __META__: %Tortoise311.Package.Meta{opcode: 3, flags: 0},\n  identifier: nil,\n  topic: \"my/first/test/topic\",\n  payload: \"hello world\",\n  qos: 0,\n  dup: false,\n  retain: false\n}\n```","ref":"PintBroker.html#module-rule-forwarding"},{"type":"function","title":"PintBroker.add_rule/3","doc":"Add a topic filter rule with handler\n\nIn many broker implementations, there are a few routing rules that forward\nmessages from specific topics to a handler such as an SQS queue or central\nservice in a fan-in pattern for scaling many remote devices to a few nodes.\n\nMany times the topic runs through a full SQL query before forwarding the\nmessage on. However, that is unsupported in this simple server. Instead\nyou can provide a simple topic filter and a handler function or process\nwhich will receive the Tortoise311.Package.Publish struct that can be split\napart by your logic to formulate into the end result needed (such as mimicing\nan SQS queue message in your producer)","ref":"PintBroker.html#add_rule/3"},{"type":"function","title":"PintBroker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PintBroker.html#child_spec/1"},{"type":"function","title":"PintBroker.publish/3","doc":"Publish a message to a topic.","ref":"PintBroker.html#publish/3"},{"type":"type","title":"PintBroker.opt/0","doc":"","ref":"PintBroker.html#t:opt/0"},{"type":"type","title":"PintBroker.rule/0","doc":"","ref":"PintBroker.html#t:rule/0"},{"type":"extras","title":"PintBroker 🍺","doc":"# PintBroker 🍺\n\n[![CircleCI](https://circleci.com/gh/jjcarstens/pint_broker.svg?style=svg)](https://circleci.com/gh/jjcarstens/pint_broker)\n[![Hex version](https://img.shields.io/hexpm/v/pint_broker.svg \"Hex version\")](https://hex.pm/packages/pint_broker)\n\nA simple, pint-sized MQTT broker that can be used for testing and development\n\n> **Warning**\n>\n> This is not indended for production use and makes no attempts for large\n> connection scaling and handling. It is also not considered feature complete,\n> but handles most simple use cases.\n\n**Supported:**\n\n* Simple, unencrypted TCP connections\n* [MQTT v3.1.1](http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.pdf)\n  * QoS 0\n  * Connect, publish, subscribe, and unsubscribe\n  * Ping requests\n  * Rule forwarding (see below)\n\n**Unsupported:**\n\n* SSL connections\n* QoS 1 and 2\n* [MQTT v5](https://docs.oasis-open.org/mqtt/mqtt/v5.0/mqtt-v5.0.pdf)","ref":"readme.html"},{"type":"extras","title":"Rule forwarding - PintBroker 🍺","doc":"Many production setups will have a few topics with rules that forward\nmessages to a handler such as an SQS queue or central service. This allows\nfor scaling of many devices to communicate with a few nodes. For testing,\nyou can specify rules when starting the broker which will forward\n`Tortoise311.Package.Publish` structs to a handler function or process in\norder to mimic this rule forwarding behavior. See `PintBroker.add_rule/3` for\nmore information.\n\n**Example:**\n\n```elixir\niex> s = self()\n\niex> handler1 = fn pub -> send(s, pub) end\n\niex> PintBroker.start_link(rules: [{\"my/+/test/topic\", handler1}])\n{:ok, #PID }\n\n# You can publish from the broker or another client\niex> PintBroker.publish(\"my/first/test/topic\", \"hello world\")\n\niex> flush()\n%Tortoise311.Package.Publish{\n  __META__: %Tortoise311.Package.Meta{opcode: 3, flags: 0},\n  identifier: nil,\n  topic: \"my/first/test/topic\",\n  payload: \"hello world\",\n  qos: 0,\n  dup: false,\n  retain: false\n}\n```","ref":"readme.html#rule-forwarding"},{"type":"extras","title":"Why _another_ broker? - PintBroker 🍺","doc":"There are many full-featured MQTT brokers out there, but they require a lot of\nsetup and configuration, maybe some dependencies, and tend to be overkill for\ntesting of MQTT interactions between client and servers. I wanted the simplest\npossible broker which did not require a full ops team to implement a test\nenvironment that clients could connect to and publish/subscribe to topics for\nimproved MQTT unit testing and local development of the whole system.","ref":"readme.html#why-_another_-broker"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v1.0.0 - 2023-09-26 - Changelog","doc":"Initial release. See [README.md](README.md) for more information.\n\n#","ref":"changelog.html#v1-0-0-2023-09-26"},{"type":"extras","title":"Added - Changelog","doc":"* Simple, unencrypted TCP connections\n* [MQTT v3.1.1](http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.pdf)\n  * QoS 0\n  * Connect, publish, subscribe, and unsubscribe\n  * Ping requests\n  * Rule forwarding (see below)","ref":"changelog.html#added"}],"content_type":"text/markdown"}